@@ -1,37 +1,38 @@
-/*
- *   Parallel port backend for OpenPrinting CUPS Filters.
- *
- *   Copyright 2007-2011 by Apple Inc.
- *   Copyright 1997-2007 by Easy Software Products, all rights reserved.
- *
- *   These coded instructions, statements, and computer programs are the
- *   property of Apple Inc. and are protected by Federal copyright
- *   law.  Distribution and use rights are outlined in the file "COPYING"
- *   which should have been included with this file.
- *
- * Contents:
- *
- *   main()         - Send a file to the specified parallel port.
- *   drain_output() - Drain pending print data to the device.
- *   list_devices() - List all parallel devices.
- *   run_loop()     - Read and write print and back-channel data.
- *   side_cb()      - Handle side-channel requests...
- */
+//
+// Parallel port backend for cups-filters.
+//
+// Copyright 2007-2011 by Apple Inc.
+// Copyright 1997-2007 by Easy Software Products, all rights reserved.
+//
+// Licensed under Apache License v2.0.  See the file "LICENSE" for more
+// information.
+//
+// Contents:
+//
+//   main()         - Send a file to the specified parallel port.
+//   drain_output() - Drain pending print data to the device.
+//   list_devices() - List all parallel devices.
+//   run_loop()     - Read and write print and back-channel data.
+//   side_cb()      - Handle side-channel requests...
+//
 
-/*
- * Include necessary headers.
- */
+//
+// Include necessary headers.
+//
 
-#include "backend-private.h"
+#include <cupsfilters/ieee1284.h>
+#include <cups/backend.h>
+#include <cups/sidechannel.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <termios.h>
+#include <stdio.h>
 #include <sys/socket.h>
 
 
-/*
- * Local functions...
- */
+//
+// Local functions...
+//
 
 static int	drain_output(int print_fd, int device_fd);
 static void	list_devices(void);
@@ -40,44 +41,45 @@ static ssize_t	run_loop(int print_fd, int device_fd, int use_bc,
 static int	side_cb(int print_fd, int device_fd, int use_bc);
 
 
-/*
- * 'main()' - Send a file to the specified parallel port.
- *
- * Usage:
- *
- *    printer-uri job-id user title copies options [file]
- */
+//
+// 'main()' - Send a file to the specified parallel port.
+//
+// Usage:
+//
+//    printer-uri job-id user title copies options [file]
+//
 
-int					/* O - Exit status */
-main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
-     char *argv[])			/* I - Command-line arguments */
+int					// O - Exit status
+main(int  argc,				// I - Number of command-line arguments
+                                        //     (6 or 7)
+     char *argv[])			// I - Command-line arguments
 {
-  char		method[255],		/* Method in URI */
-		hostname[1024],		/* Hostname */
-		username[255],		/* Username info (not used) */
-		resource[1024],		/* Resource info (device and options) */
-		*options;		/* Pointer to options */
-  int		port;			/* Port number (not used) */
-  int		print_fd,		/* Print file */
-		device_fd,		/* Parallel device */
-		use_bc;			/* Read back-channel data? */
-  int		copies;			/* Number of copies to print */
-  ssize_t	tbytes;			/* Total number of bytes written */
-  struct termios opts;			/* Parallel port options */
+  char		method[255],		// Method in URI
+		hostname[1024],		// Hostname
+		username[255],		// Username info (not used)
+		resource[1024],		// Resource info (device and options)
+		*options;		// Pointer to options
+  int		port;			// Port number (not used)
+  int		print_fd,		// Print file
+		device_fd,		// Parallel device
+		use_bc;			// Read back-channel data?
+  int		copies;			// Number of copies to print
+  ssize_t	tbytes;			// Total number of bytes written
+  struct termios opts;			// Parallel port options
 #if defined(HAVE_SIGACTION) && !defined(HAVE_SIGSET)
-  struct sigaction action;		/* Actions for POSIX signals */
-#endif /* HAVE_SIGACTION && !HAVE_SIGSET */
+  struct sigaction action;		// Actions for POSIX signals
+#endif // HAVE_SIGACTION && !HAVE_SIGSET
 
 
- /*
-  * Make sure status messages are not buffered...
-  */
+  //
+  // Make sure status messages are not buffered...
+  //
 
   setbuf(stderr, NULL);
 
- /*
-  * Ignore SIGPIPE signals...
-  */
+  //
+  // Ignore SIGPIPE signals...
+  //
 
 #ifdef HAVE_SIGSET
   sigset(SIGPIPE, SIG_IGN);
@@ -87,11 +89,11 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
   sigaction(SIGPIPE, &action, NULL);
 #else
   signal(SIGPIPE, SIG_IGN);
-#endif /* HAVE_SIGSET */
+#endif // HAVE_SIGSET
 
- /*
-  * Check command-line...
-  */
+  //
+  // Check command-line...
+  //
 
   if (argc == 1)
   {
@@ -105,10 +107,10 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
     return (CUPS_BACKEND_FAILED);
   }
 
- /*
-  * If we have 7 arguments, print the file named on the command-line.
-  * Otherwise, send stdin instead...
-  */
+  //
+  // If we have 7 arguments, print the file named on the command-line.
+  // Otherwise, send stdin instead...
+  //
 
   if (argc == 6)
   {
@@ -117,9 +119,9 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
   }
   else
   {
-   /*
-    * Try to open the print file...
-    */
+    //
+    // Try to open the print file...
+    //
 
     if ((print_fd = open(argv[6], O_RDONLY)) < 0)
     {
@@ -130,42 +132,42 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
     copies = atoi(argv[4]);
   }
 
- /*
-  * Extract the device name and options from the URI...
-  */
+  //
+  // Extract the device name and options from the URI...
+  //
 
   httpSeparateURI(HTTP_URI_CODING_ALL, cupsBackendDeviceURI(argv),
                   method, sizeof(method), username, sizeof(username),
 		  hostname, sizeof(hostname), &port,
 		  resource, sizeof(resource));
 
- /*
-  * See if there are any options...
-  */
+  //
+  // See if there are any options...
+  //
 
   if ((options = strchr(resource, '?')) != NULL)
   {
-   /*
-    * Yup, terminate the device name string and move to the first
-    * character of the options...
-    */
+    //
+    // Yup, terminate the device name string and move to the first
+    // character of the options...
+    //
 
     *options++ = '\0';
   }
 
- /*
-  * Open the parallel port device...
-  */
+  //
+  // Open the parallel port device...
+  //
 
   fputs("STATE: +connecting-to-device\n", stderr);
 
   do
   {
 #if defined(__linux) || defined(__FreeBSD__)
-   /*
-    * The Linux and FreeBSD parallel port drivers currently are broken WRT
-    * select() and bidirection I/O...
-    */
+    //
+    // The Linux and FreeBSD parallel port drivers currently are broken WRT
+    // select() and bidirection I/O...
+    //
 
     device_fd = open(resource, O_WRONLY | O_EXCL);
     use_bc    = 0;
@@ -178,25 +180,25 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
     }
     else
       use_bc = 1;
-#endif /* __linux || __FreeBSD__ */
+#endif // __linux || __FreeBSD__
 
     if (device_fd == -1)
     {
       if (getenv("CLASS") != NULL)
       {
-       /*
-        * If the CLASS environment variable is set, the job was submitted
-	* to a class and not to a specific queue.  In this case, we want
-	* to abort immediately so that the job can be requeued on the next
-	* available printer in the class.
-	*/
+	//
+        // If the CLASS environment variable is set, the job was submitted
+	// to a class and not to a specific queue.  In this case, we want
+	// to abort immediately so that the job can be requeued on the next
+	// available printer in the class.
+	//
 
         fputs("INFO: Unable to contact printer, queuing on next printer in "
               "class.\n", stderr);
 
-       /*
-        * Sleep 5 seconds to keep the job from requeuing too rapidly...
-	*/
+	//
+        // Sleep 5 seconds to keep the job from requeuing too rapidly...
+	//
 
 	sleep(5);
 
@@ -225,21 +227,21 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
 
   fputs("STATE: -connecting-to-device\n", stderr);
 
- /*
-  * Set any options provided...
-  */
+  //
+  // Set any options provided...
+  //
 
   tcgetattr(device_fd, &opts);
 
-  opts.c_lflag &= ~(ICANON | ECHO | ISIG);	/* Raw mode */
+  opts.c_lflag &= ~(ICANON | ECHO | ISIG);	// Raw mode
 
-  /**** No options supported yet ****/
+  // **** No options supported yet ****
 
   tcsetattr(device_fd, TCSANOW, &opts);
 
- /*
-  * Finally, send the print file...
-  */
+  //
+  // Finally, send the print file...
+  //
 
   tbytes = 0;
 
@@ -259,9 +261,9 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
       fputs("INFO: Print file sent.\n", stderr);
   }
 
- /*
-  * Close the socket connection and input file and return...
-  */
+  //
+  // Close the socket connection and input file and return...
+  //
 
   close(device_fd);
 
@@ -272,38 +274,38 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
 }
 
 
-/*
- * 'drain_output()' - Drain pending print data to the device.
- */
+//
+// 'drain_output()' - Drain pending print data to the device.
+//
 
-static int				/* O - 0 on success, -1 on error */
-drain_output(int print_fd,		/* I - Print file descriptor */
-             int device_fd)		/* I - Device file descriptor */
+static int				// O - 0 on success, -1 on error
+drain_output(int print_fd,		// I - Print file descriptor
+             int device_fd)		// I - Device file descriptor
 {
-  int		nfds;			/* Maximum file descriptor value + 1 */
-  fd_set	input;			/* Input set for reading */
-  ssize_t	print_bytes,		/* Print bytes read */
-		bytes;			/* Bytes written */
-  char		print_buffer[8192],	/* Print data buffer */
-		*print_ptr;		/* Pointer into print data buffer */
-  struct timeval timeout;		/* Timeout for read... */
+  int		nfds;			// Maximum file descriptor value + 1
+  fd_set	input;			// Input set for reading
+  ssize_t	print_bytes,		// Print bytes read
+		bytes;			// Bytes written
+  char		print_buffer[8192],	// Print data buffer
+		*print_ptr;		// Pointer into print data buffer
+  struct timeval timeout;		// Timeout for read...
 
 
- /*
-  * Figure out the maximum file descriptor value to use with select()...
-  */
+  //
+  // Figure out the maximum file descriptor value to use with select()...
+  //
 
   nfds = (print_fd > device_fd ? print_fd : device_fd) + 1;
 
- /*
-  * Now loop until we are out of data from print_fd...
-  */
+  //
+  // Now loop until we are out of data from print_fd...
+  //
 
   for (;;)
   {
-   /*
-    * Use select() to determine whether we have data to copy around...
-    */
+    //
+    // Use select() to determine whether we have data to copy around...
+    //
 
     FD_ZERO(&input);
     FD_SET(print_fd, &input);
@@ -320,9 +322,9 @@ drain_output(int print_fd,		/* I - Print file descriptor */
     if ((print_bytes = read(print_fd, print_buffer,
 			    sizeof(print_buffer))) < 0)
     {
-     /*
-      * Read error - bail if we don't see EAGAIN or EINTR...
-      */
+      //
+      // Read error - bail if we don't see EAGAIN or EINTR...
+      //
 
       if (errno != EAGAIN && errno != EINTR)
       {
@@ -334,9 +336,9 @@ drain_output(int print_fd,		/* I - Print file descriptor */
     }
     else if (print_bytes == 0)
     {
-     /*
-      * End of file, return...
-      */
+      //
+      // End of file, return...
+      //
 
       return (0);
     }
@@ -348,9 +350,9 @@ drain_output(int print_fd,		/* I - Print file descriptor */
     {
       if ((bytes = write(device_fd, print_ptr, print_bytes)) < 0)
       {
-       /*
-        * Write error - bail if we don't see an error we can retry...
-	*/
+	//
+        // Write error - bail if we don't see an error we can retry...
+	//
 
         if (errno != ENOSPC && errno != ENXIO && errno != EAGAIN &&
 	    errno != EINTR && errno != ENOTTY)
@@ -371,27 +373,27 @@ drain_output(int print_fd,		/* I - Print file descriptor */
 }
 
 
-/*
- * 'list_devices()' - List all parallel devices.
- */
+//
+// 'list_devices()' - List all parallel devices.
+//
 
 static void
 list_devices(void)
 {
 #ifdef __sun
   static char	*funky_hex = "0123456789abcdefghijklmnopqrstuvwxyz";
-				/* Funky hex numbering used for some devices */
-#endif /* __sun */
+				// Funky hex numbering used for some devices
+#endif // __sun
 
 #ifdef __linux
-  int	i;			/* Looping var */
-  int	fd;			/* File descriptor */
-  char	device[512],		/* Device filename */
-	basedevice[255],	/* Base device filename for ports */
-	device_id[1024],	/* Device ID string */
-	make_model[1024],	/* Make and model */
-	info[2048],		/* Info string */
-	uri[1024];		/* Device URI */
+  int	i;			// Looping var
+  int	fd;			// File descriptor
+  char	device[512],		// Device filename
+	basedevice[255],	// Base device filename for ports
+	device_id[1024],	// Device ID string
+	make_model[1024],	// Make and model
+	info[2048],		// Info string
+	uri[1024];		// Device URI
 
 
   if (!access("/dev/parallel/", 0))
@@ -403,9 +405,9 @@ list_devices(void)
 
   for (i = 0; i < 4; i ++)
   {
-   /*
-    * Open the port, if available...
-    */
+    //
+    // Open the port, if available...
+    //
 
     sprintf(device, "%s%d", basedevice, i);
     if ((fd = open(device, O_RDWR | O_EXCL)) < 0)
@@ -413,15 +415,15 @@ list_devices(void)
 
     if (fd >= 0)
     {
-     /*
-      * Now grab the IEEE 1284 device ID string...
-      */
+      //
+      // Now grab the IEEE 1284 device ID string...
+      //
 
       snprintf(uri, sizeof(uri), "parallel:%s", device);
 
-      if (!backendGetDeviceID(fd, device_id, sizeof(device_id),
-                              make_model, sizeof(make_model),
-			      NULL, uri, sizeof(uri)))
+      if (!cfIEEE1284GetDeviceID(fd, device_id, sizeof(device_id),
+			       make_model, sizeof(make_model),
+			       NULL, uri, sizeof(uri)))
       {
         snprintf(info, sizeof(info), "%s LPT #%d", make_model, i + 1);
 	cupsBackendReport("direct", uri, make_model, info, device_id, NULL);
@@ -436,13 +438,13 @@ list_devices(void)
     }
   }
 #elif defined(__sun)
-  int		i, j, n;	/* Looping vars */
-  char		device[255];	/* Device filename */
+  int		i, j, n;	// Looping vars
+  char		device[255];	// Device filename
 
 
- /*
-  * Standard parallel ports...
-  */
+  //
+  // Standard parallel ports...
+  //
 
   for (i = 0; i < 10; i ++)
   {
@@ -469,9 +471,9 @@ list_devices(void)
              device, i + 1);
   }
 
- /*
-  * MAGMA parallel ports...
-  */
+  //
+  // MAGMA parallel ports...
+  //
 
   for (i = 0; i < 40; i ++)
   {
@@ -481,15 +483,15 @@ list_devices(void)
              device, (i / 10) + 1, (i % 10) + 1);
   }
 
- /*
-  * Central Data parallel ports...
-  */
+  //
+  // Central Data parallel ports...
+  //
 
   for (i = 0; i < 9; i ++)
     for (j = 0; j < 8; j ++)
       for (n = 0; n < 32; n ++)
       {
-        if (i == 8)	/* EtherLite */
+        if (i == 8)	// EtherLite
           sprintf(device, "/dev/sts/lpN%d%c", j, funky_hex[n]);
         else
           sprintf(device, "/dev/sts/lp%c%d%c", i + 'C', j,
@@ -506,9 +508,9 @@ list_devices(void)
 	}
       }
 #elif defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__DragonFly__) || defined(__FreeBSD_kernel__)
-  int	i;			/* Looping var */
-  int	fd;			/* File descriptor */
-  char	device[255];		/* Device filename */
+  int	i;			// Looping var
+  int	fd;			// File descriptor
+  char	device[255];		// Device filename
 
 
   for (i = 0; i < 3; i ++)
@@ -531,47 +533,47 @@ list_devices(void)
 }
 
 
-/*
- * 'run_loop()' - Read and write print and back-channel data.
- */
+//
+// 'run_loop()' - Read and write print and back-channel data.
+//
 
-static ssize_t				/* O - Total bytes on success, -1 on error */
-run_loop(int print_fd,			/* I - Print file descriptor */
-	int device_fd,			/* I - Device file descriptor */
-	int use_bc,			/* I - Use back-channel? */
-	int update_state)		/* I - Update printer-state-reasons? */
+static ssize_t				// O - Total bytes on success, -1 on error
+run_loop(int print_fd,			// I - Print file descriptor
+	int device_fd,			// I - Device file descriptor
+	int use_bc,			// I - Use back-channel?
+	int update_state)		// I - Update printer-state-reasons?
 {
-  int		nfds;			/* Maximum file descriptor value + 1 */
-  fd_set	input,			/* Input set for reading */
-		output;			/* Output set for writing */
-  ssize_t	print_bytes,		/* Print bytes read */
-		bc_bytes,		/* Backchannel bytes read */
-		total_bytes,		/* Total bytes written */
-		bytes;			/* Bytes written */
-  int		paperout;		/* "Paper out" status */
-  int		offline;		/* "Off-line" status */
-  char		print_buffer[8192],	/* Print data buffer */
-		*print_ptr,		/* Pointer into print data buffer */
-		bc_buffer[1024];	/* Back-channel data buffer */
-  struct timeval timeout;		/* Timeout for select() */
-  int           sc_ok;                  /* Flag a side channel error and
-					   stop using the side channel
-					   in such a case. */
+  int		nfds;			// Maximum file descriptor value + 1
+  fd_set	input,			// Input set for reading
+		output;			// Output set for writing
+  ssize_t	print_bytes,		// Print bytes read
+		bc_bytes,		// Backchannel bytes read
+		total_bytes,		// Total bytes written
+		bytes;			// Bytes written
+  int		paperout;		// "Paper out" status
+  int		offline;		// "Off-line" status
+  char		print_buffer[8192],	// Print data buffer
+		*print_ptr,		// Pointer into print data buffer
+		bc_buffer[1024];	// Back-channel data buffer
+  struct timeval timeout;		// Timeout for select()
+  int           sc_ok;                  // Flag a side channel error and
+					// stop using the side channel
+					// in such a case.
 #if defined(HAVE_SIGACTION) && !defined(HAVE_SIGSET)
-  struct sigaction action;		/* Actions for POSIX signals */
-#endif /* HAVE_SIGACTION && !HAVE_SIGSET */
+  struct sigaction action;		// Actions for POSIX signals
+#endif // HAVE_SIGACTION && !HAVE_SIGSET
 
 
- /*
-  * If we are printing data from a print driver on stdin, ignore SIGTERM
-  * so that the driver can finish out any page data, e.g. to eject the
-  * current page.  We only do this for stdin printing as otherwise there
-  * is no way to cancel a raw print job...
-  */
+  //
+  // If we are printing data from a print driver on stdin, ignore SIGTERM
+  // so that the driver can finish out any page data, e.g. to eject the
+  // current page.  We only do this for stdin printing as otherwise there
+  // is no way to cancel a raw print job...
+  //
 
   if (!print_fd)
   {
-#ifdef HAVE_SIGSET /* Use System V signals over POSIX to avoid bugs */
+#ifdef HAVE_SIGSET // Use System V signals over POSIX to avoid bugs
     sigset(SIGTERM, SIG_IGN);
 #elif defined(HAVE_SIGACTION)
     memset(&action, 0, sizeof(action));
@@ -581,40 +583,40 @@ run_loop(int print_fd,			/* I - Print file descriptor */
     sigaction(SIGTERM, &action, NULL);
 #else
     signal(SIGTERM, SIG_IGN);
-#endif /* HAVE_SIGSET */
+#endif // HAVE_SIGSET
   }
   else if (print_fd < 0)
   {
-   /*
-    * Copy print data from stdin, but don't mess with the signal handlers...
-    */
+    //
+    // Copy print data from stdin, but don't mess with the signal handlers...
+    //
 
     print_fd = 0;
   }
 
- /*
-  * Figure out the maximum file descriptor value to use with select()...
-  */
+  //
+  // Figure out the maximum file descriptor value to use with select()...
+  //
 
   nfds = (print_fd > device_fd ? print_fd : device_fd) + 1;
 
 
- /*
-  * Side channel is OK...
-  */
+  //
+  // Side channel is OK...
+  //
 
   sc_ok = 1;
 
- /*
-  * Now loop until we are out of data from print_fd...
-  */
+  //
+  // Now loop until we are out of data from print_fd...
+  //
 
   for (print_bytes = 0, print_ptr = print_buffer, offline = -1,
-           paperout = -1, total_bytes = 0;;)
+	 paperout = -1, total_bytes = 0;;)
   {
-   /*
-    * Use select() to determine whether we have data to copy around...
-    */
+    //
+    // Use select() to determine whether we have data to copy around...
+    //
 
     FD_ZERO(&input);
     if (!print_bytes)
@@ -633,9 +635,9 @@ run_loop(int print_fd,			/* I - Print file descriptor */
 
     if (select(nfds, &input, &output, NULL, &timeout) < 0)
     {
-     /*
-      * Pause printing to clear any pending errors...
-      */
+      //
+      // Pause printing to clear any pending errors...
+      //
 
       if (errno == ENXIO && offline != 1 && update_state)
       {
@@ -653,29 +655,29 @@ run_loop(int print_fd,			/* I - Print file descriptor */
       continue;
     }
 
-   /*
-    * Check if we have a side-channel request ready...
-    */
+    //
+    // Check if we have a side-channel request ready...
+    //
 
     if (sc_ok && FD_ISSET(CUPS_SC_FD, &input))
     {
-     /*
-      * Do the side-channel request, then start back over in the select
-      * loop since it may have read from print_fd...
-      *
-      * If the side channel processing errors, go straight on to avoid
-      * blocking of the backend by side channel problems, deactivate the side
-      * channel.
-      */
+      //
+      // Do the side-channel request, then start back over in the select
+      // loop since it may have read from print_fd...
+      //
+      // If the side channel processing errors, go straight on to avoid
+      // blocking of the backend by side channel problems, deactivate the side
+      // channel.
+      //
 
       if (side_cb(print_fd, device_fd, use_bc))
 	sc_ok = 0;
       continue;
     }
 
-   /*
-    * Check if we have back-channel data ready...
-    */
+    //
+    // Check if we have back-channel data ready...
+    //
 
     if (FD_ISSET(device_fd, &input))
     {
@@ -694,18 +696,18 @@ run_loop(int print_fd,			/* I - Print file descriptor */
         use_bc = 0;
     }
 
-   /*
-    * Check if we have print data ready...
-    */
+    //
+    // Check if we have print data ready...
+    //
 
     if (FD_ISSET(print_fd, &input))
     {
       if ((print_bytes = read(print_fd, print_buffer,
                               sizeof(print_buffer))) < 0)
       {
-       /*
-        * Read error - bail if we don't see EAGAIN or EINTR...
-	*/
+	//
+        // Read error - bail if we don't see EAGAIN or EINTR...
+	//
 
 	if (errno != EAGAIN && errno != EINTR)
 	{
@@ -717,9 +719,9 @@ run_loop(int print_fd,			/* I - Print file descriptor */
       }
       else if (print_bytes == 0)
       {
-       /*
-        * End of file, break out of the loop...
-	*/
+	//
+        // End of file, break out of the loop...
+	//
 
         break;
       }
@@ -730,18 +732,18 @@ run_loop(int print_fd,			/* I - Print file descriptor */
               (int)print_bytes);
     }
 
-   /*
-    * Check if the device is ready to receive data and we have data to
-    * send...
-    */
+    //
+    // Check if the device is ready to receive data and we have data to
+    // send...
+    //
 
     if (print_bytes && FD_ISSET(device_fd, &output))
     {
       if ((bytes = write(device_fd, print_ptr, print_bytes)) < 0)
       {
-       /*
-        * Write error - bail if we don't see an error we can retry...
-	*/
+	//
+        // Write error - bail if we don't see an error we can retry...
+	//
 
         if (errno == ENOSPC)
 	{
@@ -788,27 +790,27 @@ run_loop(int print_fd,			/* I - Print file descriptor */
     }
   }
 
- /*
-  * Return with success...
-  */
+  //
+  // Return with success...
+  //
 
   return (total_bytes);
 }
 
 
-/*
- * 'side_cb()' - Handle side-channel requests...
- */
+//
+// 'side_cb()' - Handle side-channel requests...
+//
 
-static int				/* O - 0 on success, -1 on error */
-side_cb(int         print_fd,		/* I - Print file */
-        int         device_fd,		/* I - Device file */
-	int         use_bc)		/* I - Using back-channel? */
+static int				// O - 0 on success, -1 on error
+side_cb(int         print_fd,		// I - Print file
+        int         device_fd,		// I - Device file
+	int         use_bc)		// I - Using back-channel?
 {
-  cups_sc_command_t	command;	/* Request command */
-  cups_sc_status_t	status;		/* Request/response status */
-  char			data[2048];	/* Request/response data */
-  int			datalen;	/* Request/response data size */
+  cups_sc_command_t	command;	// Request command
+  cups_sc_status_t	status;		// Request/response status
+  char			data[2048];	// Request/response data
+  int			datalen;	// Request/response data size
 
 
   datalen = sizeof(data);
@@ -838,8 +840,8 @@ side_cb(int         print_fd,		/* I - Print file */
     case CUPS_SC_CMD_GET_DEVICE_ID :
         memset(data, 0, sizeof(data));
 
-        if (backendGetDeviceID(device_fd, data, sizeof(data) - 1,
-	                       NULL, 0, NULL, NULL, 0))
+        if (cfIEEE1284GetDeviceID(device_fd, data, sizeof(data) - 1,
+				NULL, 0, NULL, NULL, 0))
         {
 	  status  = CUPS_SC_STATUS_NOT_IMPLEMENTED;
 	  datalen = 0;
